function mld = find_mld (ncid,time,dpden);
%
% function mld = find_mld (ncid,time,dpden);
%
% This function computes the mixed layer depth at a particular time
% in a HOPS PE netCDF file.
%
% ------
% Input:
% ------
%
%    NCID    Identifier for open NetCDF PE/PEini file
%    TIME    Time index
%    DPDEN   Difference between surf. density and just below MLD.  (kg/m^3)
%
% -------
% Output:
% -------
%
%    MLD     Mixed layer depth.  (m)

%-------------------------------------------------------------------------------
% Initialize mixed layer depth.
%-------------------------------------------------------------------------------

name = 'tbath';
mld = ncid{name}(:);
if isempty(mld)
   disp (' ');
   disp (['***Error:  FIND_MLD - unable to read variable ',setstr(34), ...
          name,setstr(34),' in netCDF file.']);
   disp (' ');
   return;
end;

[ny nx] = size(mld);

%-------------------------------------------------------------------------------
% Determine masking.
%-------------------------------------------------------------------------------

name = 'landt';
mask = ncid{name}(:);
if isempty(mask)
   mask = ones(ny,nx);
end;

repind = find(mask==1);
filind = find(mask==0);

%-------------------------------------------------------------------------------
% Compute mixed layer depth.
%-------------------------------------------------------------------------------

tname='temp';
sname='salt';
zname='tgrid3';

for n = 1:length(repind)

   %----------------------------
   %--- Compute 2D indexing. ---
   %----------------------------

   ip = repind(n);
   j  = rem(ip,ny);
   if (j==0)
      j = ny;
   end;
   i = (ip-j)/ny + 1;

   %-------------------------------------
   %--- Read vertical column of data. ---
   %-------------------------------------

   lat = squeeze(ncid{zname}(j,i,1,2));
   if isempty(lat)
      disp (' ');
      disp (['***Error:  FIND_MLD - unable to read variable ',setstr(34), ...
             zname,setstr(34),' in netCDF file.']);
      disp (' ');
      return;
   end;
   z = squeeze(ncid{zname}(j,i,:,3));
   if isempty(z)
      disp (' ');
      disp (['***Error:  FIND_MLD - unable to read variable ',setstr(34), ...
             zname,setstr(34),' in netCDF file.']);
      disp (' ');
      return;
   end;
   temp = squeeze(ncid{tname}(time,j,i,:));
   if isempty(temp)
      disp (' ');
      disp (['***Error:  FIND_MLD - unable to read variable ',setstr(34), ...
             tname,setstr(34),' in netCDF file.']);
      disp (' ');
      return;
   end;
   salt = squeeze(ncid{sname}(time,j,i,:));
   if isempty(salt)
      disp (' ');
      disp (['***Error:  FIND_MLD - unable to read variable ',setstr(34), ...
             sname,setstr(34),' in netCDF file.']);
      disp (' ');
      return;
   end;

   %----------------------------------
   %--- Compute potential density. ---
   %----------------------------------

   p    = sw_pres(abs(z),lat)';
   pden = sw_pden(salt,temp,p,0) - 1000;

   %-------------------------------------------
   %---  Mixed layer depth is when change   ---
   %--- in density exceeds specified value. ---
   %-------------------------------------------

   dden = abs(pden - pden(1));
   ind  = min(find(dden>dpden));
   if ~isempty(ind)
      ind2 = ind - [1 0];
      mld(j,i) = interp1 (dden(ind2),z(ind2),dpden);
   end;

end;

%-------------------------------------------------------------------------------
% Extend under mask.
%-------------------------------------------------------------------------------

if ~isempty(filind)
   wk = mld;
   mld = smooth_under_iw (wk,mask);
end;
