function [ncid,timchkd] = peopen (dpden,time,pefile);
%
% function [ncid,timchkd] = peopen (dpden,time,pefile);
%
% This function opens the PE file to place in the mixed layer depth.
%
% ------
% Input:
% ------
%
%    DPDEN    Cut-off density for mixed layer.  (kg/m^3)
%    TIME     Time indices to replace.
%    PEFILE   Name of PE file to modify.
%
% -------
% Output:
% -------
%
%    NCID      Idendifier of opened PE netCDF file.
%    TIMCHKD   Time indices checked against available values.

%-------------------------------------------------------------------------------
% Set default values.
%-------------------------------------------------------------------------------

ncid    = [];
timchkd = [];
bad = 0;

%-------------------------------------------------------------------------------
% Open PE netCDF file.
%-------------------------------------------------------------------------------

ncid = netcdf (pefile,'write');

if isempty(ncid)
   disp (' ');
   disp ('***Error:  PEOPEN - unable to open PE netCDF file:');
   disp (['           ',setstr(34),pefile,setstr(34)]);
   return;
end;

%-------------------------------------------------------------------------------
% Check availability of required data.
%-------------------------------------------------------------------------------

varname = 'tbath';
if isempty(ncid{varname})
   disp (' ');
   disp (['***Error:  PEOPEN - unable to find variable ',setstr(34), ...
          varname,setstr(34),' in netCDF file.']);
   disp (' ');
   bad = 1;
end;

varname = 'tgrid3';
if isempty(ncid{varname})
   disp (' ');
   disp (['***Error:  PEOPEN - unable to find variable ',setstr(34), ...
          varname,setstr(34),' in netCDF file.']);
   disp (' ');
   bad = 1;
end;

varname = 'temp';
if isempty(ncid{varname})
   disp (' ');
   disp (['***Error:  PEOPEN - unable to find variable ',setstr(34), ...
          varname,setstr(34),' in netCDF file.']);
   disp (' ');
   bad = 1;
end;

varname = 'salt';
if isempty(ncid{varname})
   disp (' ');
   disp (['***Error:  PEOPEN - unable to find variable ',setstr(34), ...
          varname,setstr(34),' in netCDF file.']);
   disp (' ');
   bad = 1;
end;

if (bad)
   return;
end;

%-------------------------------------------------------------------------------
% Check time indices.
%-------------------------------------------------------------------------------

name = 'time';

ntim = length(ncid(name));

if isempty(ntim)
   disp (' ');
   disp (['***Error:  PEOPEN - unable to read ',setstr(34),name, ...
          setstr(34),' PE netCDF file:']);
   disp (['           ',setstr(34),pefile,setstr(34)]);
   return;
end;

ind = find (time<=ntim);
if ~isempty(ind)
   timchkd = time(ind);
 else
   disp (' ');
   disp ('***Error:  PEOPEN - no valid times to change in PE netCDF file:');
   disp (['           ',setstr(34),pefile,setstr(34)]);
   disp (['           number of time levels: ',num2str(ntim)]);
   disp (['           requested time levels: ',num2str(time)]);
   return;
end;

%-------------------------------------------------------------------------------
% Record run parameters in PE netCDF file.
%-------------------------------------------------------------------------------

%------------------------------
%--- Enter definition mode. ---
%------------------------------

varname = 'mld';
status  = redef (ncid);

if isempty(status)
   if isempty(ncid{varname})
      msg = '***Error';
      blk = '        ';
      close(ncid);
      ncid = [];
      timchkd = [];
    else
      msg = '+++Warning';
      blk = '          ';
   end
   disp (' ');
   disp ([msg,':  PEOPEN - unable to redefine PE netCDF file:']);
   disp ([blk,'   ',setstr(34),pefile,setstr(34)]);
   return;
end;

%-------------------------------------------------
%--- If necessary, define new netCDF variable. ---
%-------------------------------------------------

if isempty(ncid{varname})
   posn = 'vgrid2';
   if isempty(ncid{posn})
      posn = 'vgrid3';
   end;
   status = def_fld (ncid,varname,pefile,{'time' 'tlat' 'tlon'}, ...
                     'mixed-layer depth','meter','mixed-layer',posn,1.0e35);
   if isempty(status)
      disp (' ');
      disp (['***Error:  PEOPEN - unable to define ',setstr(34), ...
             varname,setstr(34),' PE netCDF file:']);
      disp (['           ',setstr(34),pefile,setstr(34)]);
      endef(ncid);
      close(ncid);
      ncid = [];
      timchkd = [];
      return;
   end;
end;

%--------------------------------
%--- Document run parameters. ---
%--------------------------------

attname = 'reset';
attval  = 'all or some values reset based on potential density';
eval(['ncid{varname}.',attname,' = ncchar(attval);']);
eval(['status = isempty(ncid{varname}.',attname,');']);
if (status),
   disp (' ');
   disp (['+++Warning:  PEOPEN - unable to define variable ',setstr(34), ...
          varname,':',attname,setstr(34),' in file:']);
   disp (['             ',setstr(34),pefile,setstr(34),'.']);
   disp (' ');
   return;
end;

attname = 'denrset';
attval  = dpden;
eval(['ncid{varname}.',attname,' = ncfloat(attval);']);
eval(['status = isempty(ncid{varname}.',attname,');']);
if (status),
   disp (' ');
   disp (['+++Warning:  PEOPEN - unable to define variable ',setstr(34), ...
          varname,':',attname,setstr(34),' in file:']);
   disp (['             ',setstr(34),pefile,setstr(34),'.']);
   disp (' ');
   return;
end;

attname = 'timrset';
attval  = timchkd;
eval(['ncid{varname}.',attname,' = ncshort(attval);']);
eval(['status = isempty(ncid{varname}.',attname,');']);
if (status),
   disp (' ');
   disp (['+++Warning:  PEOPEN - unable to define variable ',setstr(34), ...
          varname,':',attname,setstr(34),' in file:']);
   disp (['             ',setstr(34),pefile,setstr(34),'.']);
   disp (' ');
   return;
end;

%------------------------
%--- Enter data mode. ---
%------------------------

status  = endef (ncid);

if isempty(status)
   close(ncid);
   ncid = [];
   timchkd = [];
   disp (' ');
   disp (['***Error:  PEOPEN - unable to re-enter data mode for PE ', ...
          'netCDF file:']);
   disp (['           ',setstr(34),pefile,setstr(34)]);
   return;
end;
